/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.timedated1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef TIMEDATED_INTERFACE_H
#define TIMEDATED_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.timedate1
 */
class OrgFreedesktopTimedate1Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.timedate1"; }

public:
    OrgFreedesktopTimedate1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopTimedate1Interface();

    Q_PROPERTY(QString Timezone READ timezone)
    inline QString timezone() const
    { return qvariant_cast< QString >(property("Timezone")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> SetTimezone(const QString &timezone, bool interactive)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(timezone) << QVariant::fromValue(interactive);
        return asyncCallWithArgumentList(QStringLiteral("SetTimezone"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace freedesktop {
    using timedate1 = ::OrgFreedesktopTimedate1Interface;
  }
}

#endif
