/****************************************************************************
** Meta object code from reading C++ file 'containmentinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-workspace-6.7.3/applets/kicker/containmentinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'containmentinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ContainmentInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ContainmentInterface::qt_create_metaobjectdata<qt_meta_tag_ZN20ContainmentInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContainmentInterface",
        "QML.Element",
        "auto",
        "hasLauncher",
        "",
        "appletInterface",
        "Target",
        "target",
        "KService::Ptr",
        "service",
        "addLauncher",
        "entryPath",
        "screenContainment",
        "screenContainmentMutable",
        "ensureMutable",
        "Plasma::Containment*",
        "containment",
        "Desktop",
        "Panel",
        "TaskManager"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'hasLauncher'
        QtMocHelpers::MethodData<bool(QObject *, enum Target, const KService::Ptr &)>(3, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Method 'addLauncher'
        QtMocHelpers::MethodData<void(QObject *, enum Target, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::QString, 11 },
        }}),
        // Method 'screenContainment'
        QtMocHelpers::MethodData<QObject *(QObject *)>(12, 4, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Method 'screenContainmentMutable'
        QtMocHelpers::MethodData<bool(QObject *)>(13, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Method 'ensureMutable'
        QtMocHelpers::MethodData<void(Plasma::Containment *)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Target'
        QtMocHelpers::EnumData<enum Target>(6, 6, QMC::EnumFlags{}).add({
            {   17, Target::Desktop },
            {   18, Target::Panel },
            {   19, Target::TaskManager },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ContainmentInterface, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ContainmentInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContainmentInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContainmentInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ContainmentInterfaceE_t>.metaTypes,
    nullptr
} };

void ContainmentInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContainmentInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->hasLauncher((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Target>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KService::Ptr>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->addLauncher((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Target>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: { QObject* _r = _t->screenContainment((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->screenContainmentMutable((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->ensureMutable((*reinterpret_cast<std::add_pointer_t<Plasma::Containment*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *ContainmentInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContainmentInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContainmentInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ContainmentInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
